@@ -3,6 +3,7 @@
 Mark the start and end of the prompt with Final term (iterm2) escape sequences.
 See: https://iterm2.com/finalterm.html
 """
+
 import sys
 
 from prompt_toolkit import prompt
@@ -39,5 +40,5 @@ if __name__ == "__main__":
 
     # Output.
     sys.stdout.write(BEFORE_OUTPUT)
-    print("You said: %s" % answer)
+    print(f"You said: {answer}")
     sys.stdout.write(AFTER_OUTPUT.format(command_status=0))
