@@ -2,6 +2,7 @@
 """
 Example of a placeholder that's displayed as long as no input is given.
 """
+
 from prompt_toolkit import prompt
 from prompt_toolkit.formatted_text import HTML
 
@@ -10,4 +11,4 @@ if __name__ == "__main__":
         "Give me some input: ",
         placeholder=HTML('<style color="#888888">(please type something)</style>'),
     )
-    print("You said: %s" % answer)
+    print(f"You said: {answer}")
